@@ -104,23 +104,6 @@ toupper_shell() {
 	done
 }
 
-# try to guess the tar implementation used for `tar` on the current system
-# USAGE: guess_tar_implementation
-guess_tar_implementation() {
-	case "$(tar --version | head --lines 1)" in
-		(*'GNU tar'*)
-			PLAYIT_TAR_IMPLEMENTATION='gnutar'
-		;;
-		(*'libarchive'*)
-			PLAYIT_TAR_IMPLEMENTATION='bsdtar'
-		;;
-		(*)
-			error_unknown_tar_implementation
-			return 1
-		;;
-	esac
-}
-
 # Return the MIME type of a given file
 # USAGE: file_type $file
 # RETURNS: the MIME type, as a string
