@@ -8,9 +8,7 @@ compatibility_level() {
 	if [ -n "${PLAYIT_COMPATIBILITY_LEVEL:-}" ]; then
 		compatibility_level="$PLAYIT_COMPATIBILITY_LEVEL"
 	elif [ -n "${target_version:-}" ]; then
-		## FIXME: Find a way to show a deprecation warning *once*, not repeating it each time this function is called.
-		##        The warning should be shown when the compatibility level is set to a value ≥ 2.26.
-		compatibility_level="$target_version"
+		compatibility_level=$(compatibility_level_legacy)
 	else
 		## The bugfix version number is trimmed, to get a value respecting the expected "major.minor" format.
 		compatibility_level="${LIBRARY_VERSION%.*}"
@@ -27,6 +25,30 @@ compatibility_level() {
 	printf '%s' "$compatibility_level"
 }
 
+# Get the compatibility level from the legacy variable
+# USAGE: compatibility_level_legacy
+# RETURN: the requested compatibility level,
+#         displaying a warning if it is high enough that the legacy variable should no longer be used
+compatibility_level_legacy() {
+	## $target_version should be set when this function is called,
+	## if this is not the case it is OK to crash here because of the "nounset" shell setting
+	local compatibility_level
+	compatibility_level="$target_version"
+
+	## compatibility_level_is_at_least can not be used here, because it would rely on the current function
+	local compatibility_level_major compatibility_level_minor
+	compatibility_level_major=$(printf '%s' "$compatibility_level" | cut --delimiter='.' --fields=1)
+	compatibility_level_minor=$(printf '%s' "$compatibility_level" | cut --delimiter='.' --fields=2)
+	if
+		[ "$compatibility_level_major" -eq 2 ] &&
+		[ "$compatibility_level_minor" -ge 26 ]
+	then
+		warning_deprecated_variable 'target_version' 'PLAYIT_COMPATIBILITY_LEVEL'
+	fi
+
+	printf '%s' "$compatibility_level"
+}
+
 # Check the compatibility level against a given version
 # USAGE: compatibility_level_is_at_least $minimum_version
 # RETURN: 0 if the compatibility level is equal or superior to the given level,
