@@ -44,16 +44,13 @@ error_unknown_tar_implementation() {
 		('fr')
 			message='La version de tar présente sur ce système nʼest pas reconnue.\n'
 			message="$message"'./play.it ne peut utiliser que GNU tar ou bsdtar.\n'
-			message="$message"'Merci de signaler cette erreur sur notre outil de gestion de bugs : %s\n'
 		;;
 		('en'|*)
 			message='The tar implementation on this system wasnʼt recognized.\n'
 			message="$message"'./play.it can only use GNU tar or bsdtar.\n'
-			message="$message"'Please report this issue in our bug tracker: %s\n'
 		;;
 	esac
-	print_message 'error' "$message" \
-		"$PLAYIT_BUG_TRACKER_URL"
+	print_message 'error' "$message"
 }
 
 # Error - The given path is not a directory
@@ -108,17 +105,14 @@ error_unavailable_command() {
 	case "$messages_language" in
 		('fr')
 			message='La commande "%s" nʼest pas disponible, mais elle est requise par la fonction "%s".\n'
-			message="$message"'Merci de signaler cette erreur sur notre outil de gestion de bugs : %s\n'
 		;;
 		('en'|*)
 			message='"%s" command is not available, but it is required by function "%s".\n'
-			message="$message"'Please report this issue in our bug tracker: %s\n'
 		;;
 	esac
 	print_message 'error' "$message" \
 		"$required_command" \
-		"$function" \
-		"$PLAYIT_BUG_TRACKER_URL"
+		"$function"
 }
 
 # Error - The calling script is not compatible with the provided library version
@@ -194,7 +188,7 @@ error_variable_multiline() {
 		('fr')
 			message='La valeur %s sʼétend sur plusieurs lignes, ce qui nʼest pas autorisé.\n'
 		;;
-		('en')
+		('en'|*)
 			message='%s value is spanning multiple lines, but this is not allowed.\n'
 		;;
 	esac
@@ -215,7 +209,7 @@ error_application_wrong_type() {
 		('fr')
 			message='%s ne peut pas être appelée sur les applications utilisant le type "%s".\n'
 		;;
-		('en')
+		('en'|*)
 			message='%s can not be called on applications using "%s" type.\n'
 		;;
 	esac
