@@ -319,9 +319,6 @@ options_validity_check() {
 	option_package=$(option_value 'package')
 	case "$option_package" in
 		('arch'|'deb'|'gentoo') ;;
-		('egentoo')
-			warning_option_value_deprecated 'package' 'egentoo'
-		;;
 		(*)
 			error_option_invalid 'package' "$option_package"
 			return 1
@@ -416,6 +413,7 @@ options_compatibility_check() {
 			case "$option_package" in
 				('gentoo')
 					# --compression none has not been implemented for Gentoo packages yet.
+					# Portage tries to guess that no suffix means the configured BINPKG_COMPRESS
 					error_incompatible_options 'package' 'compression'
 					return 1
 				;;
@@ -425,8 +423,8 @@ options_compatibility_check() {
 			local option_package
 			option_package=$(option_value 'package')
 			case "$option_package" in
-				('arch')
-					# --compression auto has not been implemented for Arch Linux packages yet.
+				('arch'|'gentoo')
+					# --compression auto has not been implemented for Arch Linux and Gentoo packages yet.
 					error_incompatible_options 'package' 'compression'
 					return 1
 				;;
