@@ -1,13 +1,20 @@
-# print the id of the current game
+# Print the identifier of the current game
+# If a game is set the identifier is restricted to the characters set [-0-9a-z],
+# and can not start nor end with an hyphen (-) character.
+# An empty string is returned if no game is set yet.
 # USAGE: game_id
-# RETURN: the game id, limited to the characters set [-0-9a-z],
-#         the id can not start nor end with an hyphen (-) character
 game_id() {
-	# The game id might might be archive-specific
+	# The game identifier might might be archive-specific when several games are supported by a same script,
+	# or package-specific when several games are provided by a single archive.
 	local game_id
 	game_id=$(context_value 'GAME_ID')
 
-	# Check that the id fits the format restrictions
+	# Return early if no game identifier is set yet
+	if [ -z "$game_id" ]; then
+		return 0
+	fi
+
+	# Check that the identifier fits the format restrictions
 	if ! game_id_validity_check "$game_id"; then
 		error_game_id_invalid "$game_id"
 		return 1
