@@ -6,6 +6,15 @@ game_engine() {
 	local game_engine
 	game_engine="${GAME_ENGINE:-}"
 
+	# Try to identify games using Adventure Game Studio
+	if [ -z "$game_engine" ]; then
+		local ags_name
+		ags_name=$(ags_name)
+		if [ -n "$ags_name" ]; then
+			game_engine='ags'
+		fi
+	fi
+
 	# Try to identify games using Unity3D
 	if [ -z "$game_engine" ]; then
 		local unity3d_name
