@@ -44,3 +44,24 @@ error_requirement_too_old() {
 		"$version_required"
 }
 
+# Error - dpkg-deb is available, but its version could not be found.
+# USAGE: error_dpkg_version_not_found
+error_dpkg_version_not_found() {
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
+		('fr')
+			message='dpkg-deb est disponible, mais sa version n’a pas pu être récupérée.'
+			message="$message"'\nMerci de nous signaler cette erreur, en incluant la sortie complète de cette commande :'
+			message="$message"'\n%s\n'
+		;;
+		('en'|*)
+			message='dpkg-deb is available, but its version could not be found.'
+			message="$message"'\nPlease report this error, including the full output of the following command:'
+			message="$message"'\n%s\n'
+		;;
+	esac
+	print_message 'error' "$message" \
+		'LC_ALL=C dpkg-deb --version'
+}
+
