@@ -160,8 +160,8 @@ application_exe() {
 	printf '%s' "$application_exe"
 }
 
-# Print the full path to the application binary
-# An error is thrown if the binary file could not be found anywhere
+# Print the full path to the application binary.
+# An empty string is printed if the binary could not be found, without throwing an error.
 # USAGE: application_exe_path $application_exe
 application_exe_path() {
 	local application_exe
@@ -206,10 +206,6 @@ application_exe_path() {
 			return 0
 		fi
 	fi
-
-	# Throw an error if the binary file could not be found anywhere
-	error_application_exe_path_not_found "$application_exe"
-	return 1
 }
 
 # print the name of the given application, for display in menus
