@@ -127,26 +127,6 @@ error_application_exe_empty() {
 		"$function_name"
 }
 
-# Error - The application binary path could not be found
-# USAGE: error_application_exe_path_not_found $application_exe
-error_application_exe_path_not_found() {
-	local application_exe
-	application_exe="$1"
-
-	local messages_language message
-	messages_language=$(messages_language)
-	case "$messages_language" in
-		('fr')
-			message='Le fichier "%s" n’a pas été trouvé.\n'
-		;;
-		('en'|*)
-			message='The file "%s" could not be found.\n'
-		;;
-	esac
-	print_message 'error' "$message" \
-		"$application_exe"
-}
-
 # Error - The applications list for the current game script is empty
 # USAGE: error_applications_list_empty
 error_applications_list_empty() {
