@@ -155,7 +155,7 @@ archive_required_extra_presence_check_libpng12() {
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
-		('arch'|'egentoo'|'gentoo')
+		('arch'|'gentoo')
 			return 0
 		;;
 	esac
@@ -180,7 +180,7 @@ archive_required_extra_presence_check_libssl100() {
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
-		('arch'|'egentoo'|'gentoo')
+		('arch'|'gentoo')
 			return 0
 		;;
 	esac
@@ -205,7 +205,7 @@ archive_required_extra_presence_check_libssl11() {
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
-		('arch'|'egentoo'|'gentoo')
+		('arch'|'gentoo')
 			return 0
 		;;
 	esac
