@@ -44,24 +44,20 @@ archive_extraction_makeself() {
 	archive_bytes=$((archive_filesize % archive_block_size))
 
 	# Proceed with the contents extraction
-	local archive_extraction_return_code
-	{
+	if ! {
 		printf 'dd if="%s" ibs="%s" skip=1 obs=%s conv=sync 2>/dev/null | ' "$archive_path" "$archive_offset" "$archive_block_size"
 		printf '{ test "%s" -gt 0 && dd ibs=%s obs=%s count="%s" ; ' "$archive_blocks" "$archive_block_size" "$archive_block_size" "$archive_blocks"
 		printf 'test "%s" -gt 0 && dd ibs=1 obs=%s count="%s" ; } 2>/dev/null | ' "$archive_bytes" "$archive_block_size" "$archive_bytes"
 		printf 'gzip --stdout --decompress | tar xvf - --directory="%s"\n' "$destination_directory"
-	} >> "$log_file"
-	{
 		dd if="$archive_path" ibs="$archive_offset" skip=1 obs="$archive_block_size" conv=sync 2>/dev/null |
-			{
-				test "$archive_blocks" -gt 0 && dd ibs="$archive_block_size" obs="$archive_block_size" count="$archive_blocks"
-				test "$archive_bytes" -gt 0 && dd ibs=1 obs="$archive_block_size" count="$archive_bytes"
-			} 2>/dev/null |
-			gzip --stdout --decompress |
-			tar xvf - --directory="$destination_directory" >> "$log_file" 2>&1
-		archive_extraction_return_code=$?
-	} || true
-	if [ $archive_extraction_return_code -ne 0 ]; then
+		{
+			test "$archive_blocks" -gt 0 && dd ibs="$archive_block_size" obs="$archive_block_size" count="$archive_blocks"
+			test "$archive_bytes" -gt 0 && dd ibs=1 obs="$archive_block_size" count="$archive_bytes"
+		} 2>/dev/null |
+		gzip --stdout --decompress |
+		tar xvf - --directory="$destination_directory" 2>&1
+	} >> "$log_file"
+	then
 		error_archive_extraction_failure "$archive"
 		return 1
 	fi
