@@ -9,17 +9,16 @@ archive_extraction_using_7zr() {
 	local archive_path
 	archive_path=$(archive_path "$archive")
 
-	local extractor_options archive_extraction_return_code
+	local extractor_options
 	extractor_options=$(archive_extractor_options "$archive")
 	if [ -z "$extractor_options" ]; then
 		extractor_options='-y'
 	fi
-	printf '7zr x %s -o"%s" "%s"\n' "$extractor_options" "$destination_directory" "$archive_path" >> "$log_file"
-	{
-		7zr x $extractor_options -o"$destination_directory" "$archive_path" >> "$log_file" 2>&1
-		archive_extraction_return_code=$?
-	} || true
-	if [ $archive_extraction_return_code -ne 0 ]; then
+	if ! {
+		printf '7zr x %s -o"%s" "%s"\n' "$extractor_options" "$destination_directory" "$archive_path"
+		7zr x $extractor_options -o"$destination_directory" "$archive_path" 2>&1
+	} >> "$log_file"
+	then
 		error_archive_extraction_failure "$archive"
 		return 1
 	fi
