@@ -9,14 +9,13 @@ archive_extraction_using_dpkgdeb() {
 	local archive_path
 	archive_path=$(archive_path "$archive")
 
-	local extractor_options archive_extraction_return_code
+	local extractor_options
 	extractor_options=$(archive_extractor_options "$archive")
-	printf 'dpkg-deb --verbose %s --extract "%s" "%s"\n' "$extractor_options" "$archive_path" "$destination_directory" >> "$log_file"
-	{
-		dpkg-deb --verbose $extractor_options --extract "$archive_path" "$destination_directory" >> "$log_file" 2>&1
-		archive_extraction_return_code=$?
-	} || true
-	if [ $archive_extraction_return_code -ne 0 ]; then
+	if ! {
+		printf 'dpkg-deb --verbose %s --extract "%s" "%s"\n' "$extractor_options" "$archive_path" "$destination_directory"
+		dpkg-deb --verbose $extractor_options --extract "$archive_path" "$destination_directory" 2>&1
+	} >> "$log_file"
+	then
 		error_archive_extraction_failure "$archive"
 		return 1
 	fi
