@@ -9,7 +9,7 @@ archive_extraction_using_tar() {
 	local archive_path
 	archive_path=$(archive_path "$archive")
 
-	local extractor_options archive_extraction_return_code
+	local extractor_options
 	extractor_options=$(archive_extractor_options "$archive")
 	## Set default options based on archive type.
 	if [ -z "$extractor_options" ]; then
@@ -27,12 +27,11 @@ archive_extraction_using_tar() {
 			;;
 		esac
 	fi
-	printf 'tar --verbose %s --extract --file "%s" --directory "%s"\n' "$extractor_options" "$archive_path" "$destination_directory" >> "$log_file"
-	{
-		tar --verbose $extractor_options --extract --file "$archive_path" --directory "$destination_directory" >> "$log_file" 2>&1
-		archive_extraction_return_code=$?
-	} || true
-	if [ $archive_extraction_return_code -ne 0 ]; then
+	if ! {
+		printf 'tar --verbose %s --extract --file "%s" --directory "%s"\n' "$extractor_options" "$archive_path" "$destination_directory"
+		tar --verbose $extractor_options --extract --file "$archive_path" --directory "$destination_directory" 2>&1
+	} >> "$log_file"
+	then
 		error_archive_extraction_failure "$archive"
 		return 1
 	fi
