@@ -84,6 +84,9 @@ content_files() {
 			('ags')
 				content_files=$(ags_content_files_default "$content_id")
 			;;
+			('gamemaker')
+				content_files=$(content_files_gamemaker "$content_id")
+			;;
 			('unity3d')
 				content_files=$(unity3d_content_files_default "$content_id")
 			;;
