@@ -5,7 +5,7 @@ content_inclusion_extra_libraries() {
 	package="$1"
 
 	local libraries_required library_required
-	libraries_required=$(dependencies_list_native_libraries "$package")
+	libraries_required=$(dependencies_libraries_list "$package")
 	while read -r library_required; do
 		case "$library_required" in
 			('libcurl.so.4+CURL_OPENSSL_3')
@@ -262,7 +262,7 @@ content_inclusion_extra_libraries_libpng12() {
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
-		('arch'|'egentoo'|'gentoo')
+		('arch'|'gentoo')
 			return 0
 		;;
 	esac
@@ -318,7 +318,7 @@ content_inclusion_extra_libraries_libssl100() {
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
-		('arch'|'egentoo'|'gentoo')
+		('arch''gentoo')
 			return 0
 		;;
 	esac
@@ -373,7 +373,7 @@ content_inclusion_extra_libraries_libssl11() {
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
-		('arch'|'egentoo'|'gentoo')
+		('arch'|'gentoo')
 			return 0
 		;;
 	esac
