@@ -9,16 +9,13 @@ error_icon_file_not_found() {
 	case "$messages_language" in
 		('fr')
 			message='Le fichier dʼicône suivant est introuvable : %s\n'
-			message="$message"'Merci de signaler cette erreur sur notre outil de gestion de bugs : %s\n'
 		;;
 		('en'|*)
 			message='The following icon file could not be found: %s\n'
-			message="$message"'Please report this issue in our bug tracker: %s\n'
 		;;
 	esac
 	print_message 'error' "$message" \
-		"$file" \
-		"$PLAYIT_GAMES_BUG_TRACKER_URL"
+		"$file"
 }
 
 # Error - The path to the given icon is not set
