@@ -111,10 +111,8 @@ launcher_generation_checks() {
 	fi
 }
 
-# Check that the launcher target exists
+# Check that the launcher target exists.
 # USAGE: launcher_target_presence_check $package $application
-# RETURN: 0 if the game binary has been found,
-#         1 if the game binary has not been found
 launcher_target_presence_check() {
 	local package application
 	package="$1"
@@ -129,6 +127,12 @@ launcher_target_presence_check() {
 		set_current_package "$package"
 		application_exe_path "$application_exe"
 	)
+
+	# Failure to compute a path to the launcher target is a failure of the current test.
+	if [ -z "$application_exe_path" ]; then
+		return 1
+	fi
+
 	test -f "$application_exe_path"
 }
 
@@ -209,6 +213,7 @@ launcher_write_script() {
 				set_current_package "$package"
 				application_exe_path "$application_exe"
 			)
+			## No need to check that a non-empty path is computed, this has been checked earlier already.
 			chmod +x "$application_exe_path"
 
 			# Add dependencies on some system-provided libraries based on the game engine.
