@@ -87,26 +87,8 @@ persistent_storage_common() {
 }
 
 # Set the action used to divert a given path to persistent storage
-# This is required for the diversions using one of the following variables:
-# - FAKE_HOME_PERSISTENT_DIRECTORIES
-# - USER_PERSISTENT_DIRECTORIES
-# - WINE_PERSISTENT_DIRECTORIES
 # USAGE: persistent_path_diversion
 persistent_path_diversion() {
-	local fake_home_persistent_directories user_persistent_directories wine_persistent_directories
-	fake_home_persistent_directories=$(fake_home_persistent_directories)
-	user_persistent_directories=$(persistent_list_directories)
-	wine_persistent_directories=$(wine_persistent_directories)
-
-	# Return early if the current game script does not use paths diversion
-	if
-		[ -z "$fake_home_persistent_directories" ] &&
-		[ -z "$user_persistent_directories" ] &&
-		[ -z "$wine_persistent_directories" ]
-	then
-		return 0
-	fi
-
 	## TODO: env --chdir could be used instead of cd in a subshell.
 	cat <<- 'EOF'
 	# Replace a given directory in a prefix by a link to another directory in persistent storage
