@@ -164,7 +164,7 @@ package_provides() {
 	# PKG_BIN32       → PKG_BIN
 	# PKG_LIBS64      → PKG_LIBS
 	# PKG_LIBS32      → PKG_LIBS
-	# PKG_L10N_xxx    → PKG_L10N
+	# PKG_L10N_??     → PKG_L10N
 	if [ -z "$package_provides" ]; then
 		case "$package" in
 			('PKG_BIN64'|'PKG_BIN32')
@@ -173,7 +173,7 @@ package_provides() {
 			('PKG_LIBS64'|'PKG_LIBS32')
 				package_provides=$(package_provides 'PKG_LIBS')
 			;;
-			('PKG_L10N_'*)
+			('PKG_L10N_'??)
 				package_provides=$(package_provides 'PKG_L10N')
 			;;
 		esac
