@@ -89,16 +89,13 @@ error_package_generation_failed() {
 	case "$messages_language" in
 		('fr')
 			message='La génération du paquet suivant a échoué : %s\n'
-			message="$message"'Merci de signaler cet échec sur notre système de suivi : %s\n\n'
 		;;
 		('en'|*)
 			message='The generation of the following package failed: %s\n'
-			message="$message"'Please report this error on our bugs tracker: %s\n\n'
 		;;
 	esac
 	print_message 'error' "$message" \
-		"$package_name" \
-		"$PLAYIT_BUG_TRACKER_URL"
+		"$package_name"
 }
 
 # Error - The generation of the metadata for the given package failed.
