@@ -42,7 +42,7 @@ path_documentation() {
 		('deb'|'arch')
 			last_path_component=$(game_id)
 		;;
-		('gentoo'|'egentoo')
+		('gentoo')
 			local game_id package_version
 			game_id=$(game_id)
 			package_version=$(package_version)
@@ -106,7 +106,7 @@ path_libraries() {
 				path_structure='%s/lib32/games/%s'
 			fi
 		;;
-		('gentoo'|'egentoo')
+		('gentoo')
 			local package package_architecture
 			package=$(current_package)
 			package_architecture=$(package_architecture "$package")
@@ -150,7 +150,7 @@ path_libraries_system() {
 				;;
 			esac
 		;;
-		('gentoo'|'egentoo')
+		('gentoo')
 			case "$package_architecture" in
 				('32')
 					path_libraries='/usr/lib'
