@@ -8,7 +8,22 @@
 # USAGE: wine_virtual_desktop
 wine_virtual_desktop() {
 	local virtual_desktop
-	virtual_desktop=${WINE_VIRTUAL_DESKTOP:-none}
+	## TODO: Some game scripts would benefit from support for contextual values.
+	virtual_desktop=${WINE_VIRTUAL_DESKTOP:-}
+
+	# Fall back on the default setting for the current game engine.
+	if [ -z "$virtual_desktop" ]; then
+		local game_engine
+		game_engine=$(game_engine)
+		case "$game_engine" in
+			('unrealengine3')
+				virtual_desktop=$(wine_virtual_desktop_unrealengine3)
+			;;
+			(*)
+				virtual_desktop='none'
+			;;
+		esac
+	fi
 
 	case "$virtual_desktop" in
 		('none'|'auto') ;;
