@@ -143,7 +143,7 @@ wineprefix_init_custom() {
 wine_launcher_wineprefix_generate() {
 	cat <<- 'EOF'
 	# Generate the WINE prefix.
-	if ! [ -e "$WINEPREFIX" ]; then
+	if ! [ -e "${WINEPREFIX}/system.reg" ]; then
 	EOF
 
 	## An extra level of indentation is added to all text output by the following group of commands.
