@@ -18,16 +18,8 @@ visionaire_content_path() {
 	local content_id
 	content_id="$1"
 
-	## FIXME: This snippet used to fetch the tupe of the first application
-	##        is used in multiple places under src/55_engine-variant_*
-	##        A dedicated function, maybe with a cached value, should be provided.
-	local applications_list application application_type
-	applications_list=$(applications_list)
-	if [ -z "$applications_list" ]; then
-		error_applications_list_empty
-	fi
-	application=$(printf '%s' "$applications_list" | head --lines=1)
-	application_type=$(application_type "$application")
+	local application_type
+	application_type=$(application_default_type)
 
 	local content_path content_path_default
 	content_path_default=$(content_path_default)
@@ -67,16 +59,8 @@ visionaire_content_files() {
 	local visionaire_name
 	visionaire_name=$(visionaire_name)
 
-	## FIXME: This snippet used to fetch the tupe of the first application
-	##        is used in multiple places under src/55_engine-variant_*
-	##        A dedicated function, maybe with a cached value, should be provided.
-	local applications_list application application_type
-	applications_list=$(applications_list)
-	if [ -z "$applications_list" ]; then
-		error_applications_list_empty
-	fi
-	application=$(printf '%s' "$applications_list" | head --lines=1)
-	application_type=$(application_type "$application")
+	local application_type
+	application_type=$(application_default_type)
 
 	local content_files
 	case "$content_id" in
