@@ -45,11 +45,9 @@ visionaire_package_description() {
 	printf '%s' "${package_description:-}"
 }
 
-# Visionaire - Get the list of dependencies on siblings for the given package
-# USAGE: visionaire_package_dependencies_siblings $package
-# RETURN: a list of package identifiers,
-#         separated by line breaks
-visionaire_package_dependencies_siblings() {
+# Print identifiers of sibling packages required by Visionaire games.
+# USAGE: dependencies_siblings_list_visionaire $package
+dependencies_siblings_list_visionaire() {
 	local package
 	package="$1"
 
@@ -61,14 +59,12 @@ visionaire_package_dependencies_siblings() {
 		;;
 	esac
 
-	printf '%s' "${package_dependencies:-}" | list_clean
+	printf '%s' "${package_dependencies:-}"
 }
 
-# Visionaire - Get the list of native libraries dependencies for the given package
-# USAGE: visionaire_package_dependencies_native_libraries $package
-# RETURN: a list of native libraries,
-#         separated by line breaks
-visionaire_package_dependencies_native_libraries() {
+# Print native libraries required by Visionaire games.
+# USAGE: dependencies_libraries_list_visionaire $package
+dependencies_libraries_list_visionaire() {
 	local package
 	package="$1"
 
@@ -89,6 +85,6 @@ visionaire_package_dependencies_native_libraries() {
 		;;
 	esac
 
-	printf '%s' "${package_dependencies:-}" | list_clean
+	printf '%s' "${package_dependencies:-}"
 }
 
