@@ -32,6 +32,9 @@ initialization_default() {
 	# Set up the base archive
 	init_archive
 
+	# Check the validity of the temporary directory
+	init_working_directory_checks
+
 	# Set the default package, used by the context system when no explicit package context is set
 	init_package
 
